import fetch from 'isomorphic-unfetch'

export interface SpacebinOptions {
  host: string;
}

export class Spacebin {
  private options: SpacebinOptions
  private baseURL: string

  constructor (options: SpacebinOptions) {
    this.options = options
    this.baseURL = `${this.options.host}/api/v1`
  }

  /**
   * Get a document's content via it's ID
   *
   * @param documentID - ID of document to get
   *
   * @returns Document ID and it's content
   */
  async getDocument (documentID: string): Promise<Record<string, string>> {
    const request = await fetch(`${this.baseURL}/document/${documentID}`, {
      method: 'GET'
    })

    if (request.ok) {
      return (await request.json())
    } else {
      throw new Error(request.statusText)
    }
  }

  /**
   * Upload a document to a Spacebin instance
   *
   * @param content - Content of document to upload
   *
   * @returns Document ID and it's content
   */
  async uploadDocument (content: string): Promise<Record<string, string>> {
    const request = await fetch(`${this.baseURL}/document`, {
      method: 'POST',
      body: JSON.stringify({
        content
      }),
      headers: {
        'Content-Type': 'application/json'
      }
    })

    if (request.ok) {
      return (await request.json())
    } else {
      throw new Error(request.statusText)
    }
  }
}
